#
# spec file for package mrboom
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2018, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mrboom
Version:        5.5
Release:        1.2
Summary:        A Bomberman clone
License:        MIT
Group:          Amusements/Games/Action/Other
URL:            https://github.com/Javanaise/mrboom-libretro
Source:         https://github.com/Javanaise/mrboom-libretro/releases/download/%{version}/MrBoom-src-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(sdl2)

%description
This is an SDL2 version of the original 1999 version of Mr. Boom.
The goal of the game is to bomb away enemies and other players.

%prep
%setup -q -n MrBoom-src-%{version}

%build
export CFLAGS="%{optflags} -fPIE"
export CXXFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
make mrboom LIBSDL2=1 %{?_smp_mflags} GIT_VERSION=" SUSE"

%install
%make_install PREFIX=%{_prefix} MANDIR=share/man/man6
# icons
for i in 16x16 32x32 48x48 256x256; do
  install -D -m0644 Assets/hicolor/$i/apps/%{name}.png %{buildroot}%{_datadir}/icons/hicolor/$i/apps/%{name}.png
done
# desktop file
%suse_update_desktop_file -c %{name} %{name} "8 player Bomberman clone" %{name} %{name} Game ArcadeGame ActionGame

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man6/%{name}.6%{?ext_man}

%changelog
* Tue Jul  9 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 5.5:
  * remove autofire
  * sdl2: cap framerate to 60 FPS
- update to 5.4:
  * fix modules endings
  * add maf's zik
* Thu Dec 28 2023 Dirk Müller <dmueller@suse.com>
- update to 5.3:
  * libretro: init aspect_option variable
  * sdl2: full screen + change ignition key for 1st player
  * Fix missing settings before frontends call retro_init()
  * Apply ABGR color correction
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.2
  * AI improvements
  * Victory: Show whole team together on stage
  * Added X-mes easter egg
  * Disease: Kangaroo jumping does not contaminate
- Drop upstream merged mrboom-fix-build.patch
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.9
  * SDL2: fix linux window resizing
  * SDL2: arrow keys on GamePad(#46)
- Add patch:
  * mrboom-fix-build.patch
* Mon Apr  1 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary. Generalize description.
* Mon Feb 18 2019 Martin Hauke <mardnh@gmx.de>
- Correction of the the condition when to use the
  %%desktop_database_post macro
* Wed Jan 30 2019 mardnh@gmx.de
- Update to version 4.7
  * Bugfix release only
- Package all icons
* Tue Sep  4 2018 mardnh@gmx.de
- Initial package, version 4.5
